pub enum Input {
Text(String),
Data(Vec<u8>),
}Expand description
The query input. text for TEXT; data (raw encoded bytes — an image
file or an audio clip) for IMAGE/AUDIO. Must match modality.
Variants
Implementations
Sourceimpl Input
impl Input
Sourcepub fn merge(
field: &mut Option<Input>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Input>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.